@@ -24,7 +24,7 @@ class ProviderSwitchHandler(object):
         self.retry_when_not_found = kwargs.get('retry_when_not_found', False)
         self.providers = []
         self.current_provider = None
-        self.driver_type = kwargs.get('driver_type', 'sms')
+        self.driver_type = kwargs.get('driver_type', 'ssm')
         self._prepare()
 
     def _prepare(self) -> None:
